import { Injectable } from '@angular/core';
import { CloudObject, CloudQuery, CloudUser } from '../../../../lib/ncloud';

@Injectable({
  providedIn: 'root'
})
export class TrainingService {
  private currentUser = new CloudUser();

  constructor() { }

  async getCurrentUser() {
    return await this.currentUser.current();
  }

  async getTrainingScenarios(options?: {
    difficulty?: number;
    customerRole?: string;
    limit?: number;
    skip?: number;
    order?: string;
  }) {
    const query = new CloudQuery("TrainingScenario");
    
    if (options?.difficulty) {
      query.equalTo("difficulty", options.difficulty);
    }
    
    if (options?.customerRole) {
      query.equalTo("customerRole", options.customerRole);
    }
    
    if (options?.limit) {
      query.limit(options.limit);
    }
    
    if (options?.skip) {
      query.skip(options.skip);
    }
    
    if (options?.order) {
      const [field, direction] = options.order.split('_');
      query.orderBy(field, direction as 'asc' | 'desc');
    }
    
    return await query.find();
  }

  async createTrainingRecord(scenarioId: string, customerType: string) {
    const user = await this.getCurrentUser();
    if (!user || !user.id) throw new Error("用户未登录");
    
    const record = new CloudObject("TrainingRecord");
    record.set({
      userId: user.toPointer(),
scenarioId: new CloudObject("TrainingScenario").set({ objectId: scenarioId }),
customerType,     
      analysisResult: ""
    });
    
    return await record.save();
  }

  async updateTrainingRecordAnalysis(recordId: string, analysis: string) {
    const record = new CloudObject("TrainingRecord");
    record.set({ objectId: recordId, analysisResult: analysis });
    return await record.save();
  }

  async getUserTrainingHistory(limit: number = 10, skip: number = 0) {
    const user = await this.getCurrentUser();
    if (!user || !user.id) throw new Error("用户未登录");
    
    const query = new CloudQuery("TrainingRecord");
    query.equalTo("userId", user.toPointer());
    query.orderBy("createdAt", "desc");
    query.limit(limit);
    query.skip(skip);
    
    return await query.find();
  }

  async addCustomerType(name: string, difficulty: number, customerRole: string) {
    const scenario = new CloudObject("TrainingScenario");
    scenario.set({
      name,
      difficulty,
      customerRole,
      reactivity: 0,
      technology: 0,
      persuasiveness: 0,
      professionalism: 0
    });
    
    return await scenario.save();
  }

  async deleteCustomerType(scenarioId: string) {
    const scenario = new CloudObject("TrainingScenario");
    scenario.set({ objectId: scenarioId });
    return await scenario.destroy();
  }
}